Closed
Bug 2021630
Opened 8 months ago
Closed 8 months ago
[riscv64] Hide disassembler and debug output behind JS_DISASM_RISCV64
Categories
(Core :: JavaScript Engine: JIT, task)
Tracking
()
RESOLVED
FIXED
150 Branch
| Tracking | Status | |
|---|---|---|
| firefox150 | --- | fixed |
People
(Reporter: csmantle, Assigned: csmantle)
References
(Blocks 1 open bug)
Details
Attachments
(1 external file, 2 obsolete files)
| Assignee | ||
Updated•8 months ago
|
Assignee: nobody → webmaster
Status: NEW → ASSIGNED
Hardware: Unspecified → RISCV64
| Assignee | ||
Updated•8 months ago
|
Blocks: sm-riscv64
| Assignee | ||
Comment 1•8 months ago
|
||
| Assignee | ||
Comment 2•8 months ago
|
||
- Assembler::instr_at_put -> Assembler::putInstrAt
- Assembler::is_near -> Assembler::isNear
| Assignee | ||
Comment 3•8 months ago
|
||
| Assignee | ||
Comment 4•8 months ago
|
||
Comment on attachment 9550724 [details]
Bug 2021630 - [riscv64] Part 3: (Drive-by) Remove definitely unused #include stmts. r=jandem
This should go into a dedicated stack for RV64-specific cleanup.
Attachment #9550724 -
Attachment is obsolete: true
| Assignee | ||
Comment 5•8 months ago
•
|
||
Some ARES6 perf results:
After
Running... Air ( 1 to go)
firstIteration: 498.21 +- 3.80 ms
averageWorstCase: 186.61 +- 1.39 ms
steadyState: 82.35 +- 1.28 ms
summary: 331.78 +- 2.31 ms
Running... Basic ( 1 to go)
firstIteration: 260.83 +- 7.24 ms
averageWorstCase: 138.39 +- 3.39 ms
steadyState: 122.80 +- 4.53 ms
summary: 331.78 +- 2.31 ms
Running... Babylon ( 1 to go)
firstIteration: 480.13 +- 14.84 ms
averageWorstCase: 205.47 +- 14.40 ms
steadyState: 146.61 +- 1.00 ms
summary: 331.78 +- 2.31 ms
Running... ML ( 1 to go)
firstIteration: 1645.06 +- 33.76 ms
averageWorstCase: 1477.98 +- 37.87 ms
steadyState: 1466.82 +- 33.10 ms
summary: 331.22 +- 2.26 ms
Success! Benchmark is now finished.
Before
Running... Air ( 1 to go)
firstIteration: 505.21 +- 10.86 ms
averageWorstCase: 187.75 +- 1.33 ms
steadyState: 81.61 +- 0.69 ms
summary: 333.05 +- 3.96 ms
Running... Basic ( 1 to go)
firstIteration: 261.87 +- 13.61 ms
averageWorstCase: 136.59 +- 5.82 ms
steadyState: 117.97 +- 4.42 ms
summary: 333.05 +- 3.96 ms
Running... Babylon ( 1 to go)
firstIteration: 500.13 +- 17.90 ms
averageWorstCase: 204.70 +- 8.58 ms
steadyState: 148.39 +- 2.45 ms
summary: 333.05 +- 3.96 ms
Running... ML ( 1 to go)
firstIteration: 1675.23 +- 35.80 ms
averageWorstCase: 1509.35 +- 36.54 ms
steadyState: 1490.10 +- 34.28 ms
summary: 333.05 +- 2.99 ms
Success! Benchmark is now finished.
Env
Platform: SpacemiT M1
Base commit:
commit 46fa95cd7f10222996ec267947ab94c5107b1475
Merge: 12d718e2a70 f027136b53e
Author: Lando <lando@lando.test>
Date: Thu Mar 5 21:48:37 2026 +0000
Merge autoland to mozilla-central
Related mozconfig flags:
ac_add_options --disable-debug
ac_add_options --enable-debug-symbols
ac_add_options --enable-optimize
ac_add_options --disable-jitdump
ac_add_options --disable-jitspew
Updated•8 months ago
|
Attachment #9550721 -
Attachment description: Bug 2021630 - [riscv64] Part 1: Hide calls to disassembleInstr in non-Simulator code behind JS_DISASM_RISCV64. r=jandem → Bug 2021630 - [riscv64] Hide calls to disassembleInstr in non-Simulator code behind JS_DISASM_RISCV64. r=jandem
Updated•8 months ago
|
Attachment #9550723 -
Attachment is obsolete: true
Pushed by webmaster@csmantle.top:
https://github.com/mozilla-firefox/firefox/commit/e1a76609dda9
https://hg.mozilla.org/integration/autoland/rev/3c1947c997b9
[riscv64] Hide calls to disassembleInstr in non-Simulator code behind JS_DISASM_RISCV64. r=jandem
Comment 7•8 months ago
|
||
| bugherder | ||
Status: ASSIGNED → RESOLVED
Closed: 8 months ago
status-firefox150:
--- → fixed
Resolution: --- → FIXED
Target Milestone: --- → 150 Branch
Comment 8•8 months ago
|
||
| bugherder | ||
Updated•7 months ago
|
QA Whiteboard: [qa-triage-done-c151/b150]
You need to log in
before you can comment on or make changes to this bug.
Description
•